%{
	#include "parser.h"
	enum Attr
	{
		PUBLIC,
		PRIVATE,
		PROTECTED,
		STATIC,
		FINAL,
		ABSTRACT,
		NATIVE,
		SYNCHRONIZED,
		TRANSIENT,
		VOLATILE,
		HAS_BODY
	};
%}
identifier	[_a-zA-Z]+[_a-zA-Z0-9]*
decimalNumber	[0-9]+
blanks		[ \t\n]+

%%

<INITIAL>"." return(DOT);
<INITIAL>"*" return(STAR);
<INITIAL>";" return(SEMICOLON);
<INITIAL>"package"{blanks}+ return(PACKAGE);
<INITIAL>"import"{blanks}+ return(IMPORT);
<INITIAL>"extends"{blanks}+ return(EXTENDS);
<INITIAL>"implements"{blanks}+ return(IMPLEMENTS);

<INITIAL>"{" return(BLOCK_START);
<INITIAL>"}" return(BLOCK_END);
<INITIAL>"(" return(METHOD_ARGUMENTS_START);
<INITIAL>")" return(METHOD_ARGUMENTS_END);
<INITIAL>"<" return(GENERIC_START);
<INITIAL>">" return(GENERIC_END);
<INITIAL>"," return(COMMA);
<INITIAL>"=" return(EQUALS);

<INITIAL>"class"{blanks}+ return(CLASS_HEADER);

<INITIAL>"public"{blanks}+ {
	yylval.dval = PUBLIC;
	return(ATTRIBUTE);
}
<INITIAL>"private"{blanks}+ {
	yylval.dval = PRIVATE;
	return(ATTRIBUTE);
}
<INITIAL>"protected"{blanks}+ {
	yylval.dval = PROTECTED;
	return(ATTRIBUTE);
}

<INITIAL>"static"{blanks}+ {
	yylval.dval = STATIC;
	return(ATTRIBUTE);
}

<INITIAL>"final"{blanks}+ {
	yylval.dval = FINAL;
	return(ATTRIBUTE);
}

<INITIAL>"abstract"{blanks}+ {
	yylval.dval = ABSTRACT;
	return(ATTRIBUTE);
}

<INITIAL>"native"{blanks}+ {
	yylval.dval = NATIVE;
	return(ATTRIBUTE);
}

<INITIAL>"synchronized"{blanks}+ {
	yylval.dval = SYNCHRONIZED;
	return(ATTRIBUTE);
}

<INITIAL>"transient"{blanks}+ {
	yylval.dval = TRANSIENT;
	return(ATTRIBUTE);
}

<INITIAL>"volatile"{blanks}+ {
	yylval.dval = VOLATILE;
	return(ATTRIBUTE);
}

<INITIAL>{identifier} {
	yylval.sval = malloc(strlen((char*)yytext)+1);
	strncpy(yylval.sval, yytext, strlen((char*)yytext));
	yylval.sval[strlen((char*)yytext)] = 0;
	return(IDENTIFIER);
}

<INITIAL>{decimalNumber} return(DECNUMBER);
<INITIAL>{blanks} { /* nic */ }
<INITIAL>. return(SOMETHING);

